# German ASA Questionnaire Translation - Part 1: Translation and Formative Assessment

## Translation Round 1

**Author**: Boleslav Khodakov
**Date**: June 2023

**Contributors**: Boleslav Khodakov, Emma Bokel, Nele Albers, Andrea Bönsch, Jonathan Ehret, and Willem-Paul Brinkman.

**OSF pre-registration:** https://osf.io/adknw

**This codebase is based on code from:** Fengxiang Li

This file is meant to guide you through the steps to calculate ICC values for the first translation round.

For the first translation round, the translations of 90 English items are evaluated. There are a total of 100 translations, as some items have multiple alternative translations. These are 'Q_E_HLB5', 'Q_E_AL1', 'Q_E_AS1', 'Q_E_AS2', 'Q_E_UE2', 'Q_E_UT2', 'Q_E_UAL1'.

Out of 60 participants (30 per questionnaire), 57 recommended using their data.


### Explanation of Steps Taken

The files in this folder were used to calculate item-level ICC values for the first round of German translations of English ASA questionnaire items. Data was acquired from the survey platform Qualtrics, while recruiting participants for the study was done via Prolific. 

For round 1 of the translations, two surveys were created (to reduce fatigue of participants) - the first and second halves of the ASA questionnaire items, with their corresponding translations. 

Data from these surveys was first pre-processed. Herewith, the data was first redundantly checked (e.g. for passing attention checks), then unnecessary columns (e.g. attention checks) were removed, leaving only columns of questionnaire items (English and German). The questionnaire items were of both halves were combined, and their ICC values were calculated. 

There were 14 attention checks (in each of the two surveys), which participants had to pass for their data to be valid. 7 are in English, 7 are in German (they differ per survey). 

Initially, in the survey all items had arbitrary names (e.g. Q_ITEMS_372). During pre-processing, the labels of question items are changed to reflect a) the language of the item (prefix Q_E = English, prefix Q_DE = German), and b) the name from the original ASA questionnaire (e.g. HLA1). In the file `Final_ASA_German_Round_1_legend.txt`, items can be referenced by both their original and changed names. Attention checks were also renamed to "AttentionCheck_E/DE..." (E = English, DE = German). They can also be referenced by their old and new names in the legend file.

Some English items have multiple translations. For multiple translations, we duplicated English items (such that each English item matches one German item). English items with multiple translations are suffixed with a number (e.g. _2). This happens during preprocessing.

In the survey, we asked participants on whether they recommend using their data for research purposes. We also calculated ICC scores based only on the recommended data. A German translation was considered successful if it had an ICC score of 0.6 or higher both when using data forom all participants and when using only recommended data. English items that had no "high-ICC" (>0.6) German translations were retranslated. Those translations were evaluated in round 2.


### Examine Output of Code Run by Us

To see the transformation of the Qualtrics data into the format used for ICC calculation, access the files Data `Data Transformation Round 1 first half` (`.pdf` or `.rmd`) and `Data Transformation Round 1 second half` (`.pdf` or `.rmd`).
To see the calculation of ICC values, access the file `ICC calculation Round 1` (`.pdf` or `.rmd`).


### Run Code Yourself

This section is to explain how you can run the code yourself.


#### Requirements

You need to have the R programming language installed. Version 4.2.3 was used for this study. We recommend using RStudio to view the `.rmd` files. The `.rmd` files contain code chunks which list/install the necessary dependencies.


#### Steps to Reproduce Analyses

The reproduction of our code is based on RStudio. Take the following steps:

1. Make sure you have R installed. 
2. Open the file `Data Transformation Round 1 first half.rmd`. Run the file's contents. The file accesses the file `Final_ASA_German_Round_1_First_Half_anonym.sav`, which is the anonymized data from Qualtrics.
3. Open the file `Data Transformation Round 1 second half.rmd`. Run the file's contents. The file accesses the file `Final_ASA_German_Round_1_Second_Half_anonym.sav`, which is the anonymized data from Qualtrics.
4. In the directory where the `.rmd` files were run, 4 new files should appear. By default, they will be named `transformed_data_round_1_half_1.sav` , `transformed_data_round_1_half_1_recommended.sav` and `transformed_data_round_1_half_2.sav`, `transformed_data_round_1_half_2_recommended.sav`. This is the preprocessed data.
5. Open the file `ICC calculation Round 1.rmd`. Run the file's contents. The file should access `transformed_data_round_1_half_1.sav` and `transformed_data_round_1_half_2.sav`. 
6. Once run, `ICC calculation Round 1.rmd` will print the ICC values of individual items, the Grand Mean, Standard Deviation, Minimum and Maximum ICC values. We recommend knitting the `.rmd` files to PDF, if you want to save this data: The PDF  contains code, comments and printed ICC values.
7. The file `ICC calculation Round 1.rmd` also creates the file `ICC_output.txt` once run. This file contains questionnaire items which have an ICC value below `0.6`. The file is appended with each consecutive run of `ICC calculation Round 1.rmd`. If you run `ICC calculation Round 1.rmd` more than once, `ICC_output.txt` will have duplicate entries.


#### A Note on Knitting R Markdown

Knitting the `.rmd` files into `.pdf` files requires `.tex` and `.bib` files. These are present in the current directory. Data files needed for the `.rmd` code chunks are also present in this directory.

You may want to install dependencies present in the first code chunk of the `.rmd` file you wish to knit. If you have these installed, pressing the `knit` button in Rstudio should knit your file to PDF.


### Explanation of Files

Please note: The `.rmd` files contain extensive comments.

This directory contains the following files:

- `README.md` and `README.pdf`: Short explanations of how to use files in current folder, and what those files are.
- `Final_ASA_German_Round_1_First_Half_anonym.sav`: Qualtrics data for the "first half" survey. This survey contains the first 44 English items of the ASA questionnaire and their translations.
- `Final_ASA_German_Round_1_legend.txt`: Legend for all columns of `Final_ASA_German_Round_1_First_Half_anonym.sav`, `Final_ASA_German_Round_1_Second_Half_anonym.sav`, and consequently also all columns of `transformed_data_round_1_half_1.sav`, `transformed_data_round_1_half_2.sav`.
- `Final_ASA_German_Round_1_Second_Half_anonym.sav`: Qualtrics data for the "second half" survey. This survey contains the last 46 English items of the ASA questionnaire and their translations.
- `Data Transformation Round 1 first half.rmd/pdf`: Pre-processing of the Qualtrics data into usable data for ICC calculation for the "first half" survey. Both all-participant data and recommended-participant data are pre-processed.
- `Data Transformation Round 1 second half.rmd/pdf`: Pre-processing of the Qualtrics data into usable data for ICC calculation for the "second half" survey. Both all-participant data and recommended-participant data are pre-processed.
- `transformed_data_round_1_half_1.sav`: Pre-processed data for the "first half" survey. Based on data of all participants. Ready for ICC calculations.
- `transformed_data_round_1_half_1_recommended.sav`: Pre-processed data for the "first half" survey. Based on data of recommended participants. Ready for ICC calculations. 
- `transformed_data_round_1_half_2.sav`: Pre-processed data for the "second half" survey. Based on data of all participants. Ready for ICC calculations.
- `transformed_data_round_1_half_2_recommended.sav`: Pre-processed data for the "second half" survey. Based on data of recommended participants. Ready for ICC calculations.
- `ICC calculation Round 1.rmd/pdf`: ICC calculations on the pre-processed data (incl. "all" and "recommended").
- `prolific_export_german_first_half_anonym.csv`: General data on participants for the "first half" survey obtained from Prolific (e.g., age, gender).
- `prolific_export_german_second_half_anonym.csv`: General data on participants for the "first half" survey obtained from Prolific (e.g., age, gender).
- `prolific_export_german_legend.txt`: Legend for all columns of `prolific_export_german_first_half_anonym.csv` and `prolific_export_german_second_half_anonym.csv`. 