# German ASA Questionnaire Translation - Part 1: Translation and Formative Assessment

## Translation Round 2

**Author**: Boleslav Khodakov
**Date**: June 2023

**Contributors**: Boleslav Khodakov, Emma Bokel, Nele Albers, Andrea Bönsch, Jonathan Ehret, and Willem-Paul Brinkman.

**OSF pre-registration:** https://osf.io/adknw

**This codebase is based on code from:** Fengxiang Li


This file is meant to guide you through the steps to calculate ICC values for the second translation round.

For the second translation round, 35 English items were retranslated. Several item had multiple translations, leading to a total of 78 translations.

Out of 30 participants, 29 recommended using their data for research.


### Explanation of Steps Taken

The files in this folder were used to calculate item-level ICC values for the second round of German translations of English ASA questionnaire items. Data was acquired using the survey platform Qualtrics, while recruiting participants for the study was done via Prolific. 

For round 2 of the translations, one survey was created. It contained English ASA questionnaire items, with their corresponding translations.
 
Data from the survey was first pre-processed. Herewith, the data was first redundantly checked (e.g. for passing attention checks), then unnecessary  columns (e.g. attention checks) were removed, leaving only columns with questionnaire items (English and German). The item-wise ICC values were then calculated. 

There were 14 attention checks which participants had to pass for their data to be valid. 7 are in English, 7 are in German. 

The labels of question items are made to reflect a) the language of the item (prefix Q_E = English, prefix Q_DE = German), and b) the name from the original ASA questionnaire (e.g. HLA1). In the file `Final_ASA_German_Round_2_anonym_legend.txt`, the specific items for all columns can be found. Attention checks were also named to "AC_E/DE..." (E = English, DE = German). They can also be referenced in the legend file. For the future, we highly recommend calling Attention checks "AttentionCheck_E/DE...", because some question items may have the combination "AC" in their name which will lead to problems in the pre-processing code. In our case, this did not happen.

Some English items have multiple translations. For multiple translations, we duplicated English items (such that each English item matches one German item). English items with multiple translations are suffixed with a number (e.g. _2). This happens during preprocessing.

In the survey, we asked participants on whether they recommend using their data for research purposes. We also calculated ICC scores based only on the recommended data. A German translation was considered successful if it had an ICC score of 0.6 or higher both when using data for all participants and when using only recommended data. English items that had no "high-ICC" (>0.6) German translations were retranslated. Those new translations were evaluated in round 3.


### Examine Output of Code Run by Us

To see the transformation of the Qualtrics data into the format used for ICC calculation, access the file `Data Transformation Round 2` (`.pdf` or `.rmd`).
To see the calculation of ICC values, access the file `ICC calculation Round 2` (`.pdf` or `.rmd`).


### Run Code Yourself

This section is to explain how you can run the code yourself.


#### Requirements

You need to have the R programming language installed. Version 4.2.3 was used for this study. We recommend using RStudio to view the `.rmd` files. The `.rmd` files contain code chunks which list/install the necessary dependencies.


#### Steps to Reproduce Analyses

The reproduction of our code is based on RStudio. Take the following steps:

1. Make sure you have R installed. 
2. Open the file `Data Transformation Round 2.rmd`. Run the file's contents. The file accesses the file `Final_ASA_German_Round_2_anonym.sav`, which is the anonymized Qualtrics data.
3. In the directory where the `.rmd` files were run, two new files should appear. By default, they will be named `transformed_data_round_2.sav` and `transformed_data_round_2_recommended.sav`. This is the pre-processed data.
4. Open the file `ICC calculation Round 2.rmd`. Run the file's contents. The file should access `transformed_data_round_2.sav`. 
5. Once run, `ICC calculation Round 2.rmd` will print the ICC values of individual items, the Grand Mean, Standard Deviation, Minimum and Maximum ICC values.
6. The file `ICC calculation Round 2.rmd` also creates the file `ICC_output.txt` once run. This file contains combination of questionnaire items which have an ICC value below `0.6`. The file is appended with each consecutive run of `ICC calculation Round 2.rmd`. If you run `ICC calculation Round 2.rmd` more than once, `ICC_output.txt` will have duplicate entries.


#### A Note on Knitting R Markdown

Knitting the `.rmd` files into `.pdf` files requires `.tex` and `.bib` files. These are present in the current directory. Data files needed for the `.rmd` code chunks are also present in this directory.

You may want to install dependencies present in the first code chunk of the `.rmd` file you wish to knit. If you have these installed, pressing the `knit` button in Rstudio should knit your file to PDF.


### Explanation of Files

Please note: The `.rmd` files contain extensive comments.

This directory contains the following files:

- `README.md` and `README.pdf`: Short explanations of how to use files in the current folder, and what those files are.
- `Final_ASA_German_Round_2_anonym.sav`: Qualtrics data for the survey. This survey contained English items of the ASA questionnaire which did not have a fitting translation in round 1 and their new translations.
- `Final_ASA_German_Round_2_anonym_legend.txt`: Legend for all columns of `Final_ASA_German_Round_2_anonym.sav`, and consequently also all columns of `transformed_data_round_2.sav`.
- `Data Transformation Round 2.rmd/pdf`: Pre-processing of the Qualtrics data into usable data for ICC calculation. Both all-participant data and recommended-participant data are pre-processed.
- `transformed_data_round_2.sav`: Pre-processed data. Based on data of all participants. Ready for ICC calculations.
- `transformed_data_round_2_recommended.sav`: Pre-processed data. Based on data of recommended participants. Ready for ICC calculations.
- `ICC calculation Round 2.rmd/pdf`: ICC calculations on all pre-proccessed data (incl. "all" and "recommended").
- `prolific_export_german_anonym.csv`: General data on participants obtained from Prolific (e.g., age, gender).
- `prolific_export_german_anonym_legend.txt`: Legend for all columns of `prolific_export_german_anonym.csv`.