# German ASA Questionnaire Translation - Part 1: Translation and Formative Assessment

## Translation Round 3

**Author**: Boleslav Khodakov
**Date**: June 2023

**Contributors**: Boleslav Khodakov, Emma Bokel, Nele Albers, Andrea Bönsch, Jonathan Ehret, and Willem-Paul Brinkman.

**OSF pre-registration:** https://osf.io/adknw

**This codebase is based on code from:** Fengxiang Li


This file is meant to guide you through the steps to calculate the ICC values for the third translation round.

For the third translation round, 13 English items were retranslated. One such item ('Q_E_UEP2 ') was missed from round 1 (should have been retranslated in round 2). This was due to a rounding error. Another item, Q_E_AT2, had a German translation "too similar" to another item and was thus also retranslated to possibly obtain a more reliable and less similar translation. Overall, each item had 4 translations, leading to a total of 52 translations. 


### Explanation of Steps Taken

The files in this folder were used to calculate item-level ICC values for the third round of evaluating German translations of English ASA questionnaire items. Data was acquired using the survey platform Qualtrics, while recruiting participants for the study was done via Prolific. 

For round 3 of the translations, one survey was created. It contained 13 English ASA questionnaire items, with their corresponding German translations. 

Data from the survey was first pre-processed. Herewith, the data was first redundantly checked (e.g., for passing attention checks), then unnecessary  columns (e.g. attention checks) were removed, leaving only columns with questionnaire items (English and German). The item-wise ICC values were then calculated. 

There were 10 attention checks, which participants had to pass for their data to be valid. 3 attention checks were in English, 7 were in German. 

The labels of questionnaire items are made to reflect a) the language of the item (prefix Q_E = English, prefix Q_DE = German), and b) the name from the original ASA questionnaire (e.g. HLA1). The file "Final_ASA_German_Round_3_anonym_legend.txt" describes each column in the Qualtrics dataset. Attention checks were also named to "AC_E/DE..." (E = English, DE = German). They can also be referenced in the legend file.

Some English items have multiple translations. For multiple translations, we duplicated English items (such that each English item matches one German item). English items with multiple translations are suffixed with a number (e.g. _2). This happens during preprocessing.

In the survey, we asked participants whether they recommend using their data for research purposes. All 30 participants recommended using their data.


### Examine Output of Code Run by Us

To see the transformation of the Qualtrics data into the format used for the item-wise ICC calculation, access the file `Data Transformation Round 3` (`.pdf` or `.rmd`).

To see the calculation of ICC values, access the file `ICC calculation Round 3` (`.pdf` or `.rmd`).


### Run Code Yourself

This section is to explain how you can run the code yourself.


#### Requirements

You need to have the R programming language installed. Version 4.2.3 was used for this study. We recommend using RStudio to view the `.rmd` files. The `.rmd` files contain code chunks which list/install the necessary dependencies.


#### Steps to Reproduce Analyses

The reproduction of our code is based on RStudio. Take the following steps:

1. Make sure you have R installed. 
2. Open the file `Data Transformation Round 3.rmd`. Run the file's contents. The file accesses the file `Final_ASA_German_Round_3_anonym.sav`, which contains the anonymized Qualtrics data.
3. In the directory where the `.rmd` files were run, a new file should appear. By default, it will be named `transformed_data_round_3.sav`. This is the pre-processed data.
4. Open the file `ICC calculation Round 3.rmd`. Run the file's contents. The file should access `transformed_data_round_3.sav`. 
5. Once run, `ICC calculation Round 3.rmd` will print the ICC values of individual items, the Grand Mean, Standard Deviation, Minimum and Maximum ICC values.
6. The file `ICC calculation Round 3.rmd` also creates the file `ICC_output.txt` once run. This file contains questionnaire items which have an ICC value below `0.6`. The file is appended with each consecutive run of `ICC calculation Round 3.rmd`. If you run `ICC calculation Round 3.rmd` more than once, `ICC_output.txt` will have duplicate entries.


#### A Note on Knitting R Markdown

Knitting the `.rmd` files into `.pdf` files requires `.tex` and `.bib` files. These are present in the current directory. Data files needed for the `.rmd` code chunks are also present in this directory.

You may want to install dependencies present in the first code chunk of the `.rmd` file you wish to knit. If you have these installed, pressing the `knit` button in Rstudio should knit your file to PDF.


### Explanation of Files

Please note: The `.rmd` files contain extensive comments.

This directory contains the following files:

- `README.md` and `README.pdf`: Short explanations of how to use files in current folder, and what those files are.
- `Final_ASA_German_Round_3_anonym.sav`: Qualtrics data for the survey containing the raitings for English items and their German translations.
- `Final_ASA_German_Round_3_anonym.txt`: Legend for all columns of `Final_ASA_German_Round_3_anonym.sav`.
- `Data Transformation Round 3.rmd/pdf`: Pre-processing of the Qualtrics data into usable data for ICC calculation.
- `transformed_data_round_3.sav`: Pre-processed data. Ready for ICC calculations.
- `ICC calculation Round 3.rmd/pdf`: ICC calculations on the pre-proccessed data.
- `prolific_export_german_round3_anonym.csv`: Prolific profile data of participants (e.g., age, gender).
- `prolific_export_german_round3_anonym_legend.txt`: Legend for all columns of `prolific_export_german_anonym.csv`.
